@@ -808,8 +808,10 @@ e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, const char *ca
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 	g_return_if_fail (calobj != NULL);
 
-	g_assert (CLASS (backend)->create_object != NULL);
-	(* CLASS (backend)->create_object) (backend, cal, calobj);
+	if (CLASS (backend)->create_object)
+		(* CLASS (backend)->create_object) (backend, cal, calobj);
+	else
+		e_data_cal_notify_object_created (cal, GNOME_Evolution_Calendar_PermissionDenied, NULL, NULL);
 }
 
 void
@@ -819,8 +821,10 @@ e_cal_backend_modify_object (ECalBackend *backend, EDataCal *cal, const char *ca
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 	g_return_if_fail (calobj != NULL);
 
-	g_assert (CLASS (backend)->modify_object != NULL);
-	(* CLASS (backend)->modify_object) (backend, cal, calobj, mod);
+	if (CLASS (backend)->modify_object)
+		(* CLASS (backend)->modify_object) (backend, cal, calobj, mod);
+	else
+		e_data_cal_notify_object_removed (cal, GNOME_Evolution_Calendar_PermissionDenied, NULL, NULL);
 }
 
 /**
@@ -852,7 +856,7 @@ e_cal_backend_receive_objects (ECalBackend *backend, EDataCal *cal, const char *
 	g_return_if_fail (calobj != NULL);
 
 	g_assert (CLASS (backend)->receive_objects != NULL);
-	return (* CLASS (backend)->receive_objects) (backend, cal, calobj);
+	(* CLASS (backend)->receive_objects) (backend, cal, calobj);
 }
 
 void
@@ -863,7 +867,7 @@ e_cal_backend_send_objects (ECalBackend *backend, EDataCal *cal, const char *cal
 	g_return_if_fail (calobj != NULL);
 
 	g_assert (CLASS (backend)->send_objects != NULL);
-	return (* CLASS (backend)->send_objects) (backend, cal, calobj);
+	(* CLASS (backend)->send_objects) (backend, cal, calobj);
 }
 
 /**
@@ -1046,7 +1050,7 @@ e_cal_backend_notify_object_modified (ECalBackend *backend,
 			e_data_cal_view_notify_objects_modified_1 (query, object);
 		else if (new_match)
 			e_data_cal_view_notify_objects_added_1 (query, object);
-		else /* if (old_match) */ {
+		else if (old_match) {
 			icalcomponent *comp;
 
 			comp = icalcomponent_new_from_string ((char *)old_object);
@@ -1076,7 +1080,7 @@ e_cal_backend_notify_object_modified (ECalBackend *backend,
  **/
 void
 e_cal_backend_notify_object_removed (ECalBackend *backend, const char *uid,
-				   const char *old_object)
+				     const char *old_object)
 {
 	ECalBackendPrivate *priv;
 	EList *queries;
